Crate greengold

Crate greengold 

Structs

NullExtender
Stack

Enums

Data
Error
Pair

Traits

AtomExtender

Functions

run
Run some code. The stack and memory parameters can be non-empty; this is how data is passed to a Forth function. Since they are only borrowed return values can be extracted from them.