Crate greengold
greengold
0.2.1
All Items
Crate Items
Structs
Enums
Traits
Functions
Crate
greengold
Structs

Null
Extender
Stack
Enums

Data
Error
Pair
Traits

Atom
Extender
Functions

run
Run some code. The stack and memory parameters can be non-empty; this is how data is passed to a Forth function. Since they are only borrowed return values can be extracted from them.